# References


## alembic

https://alembic.sqlalchemy.org/en/latest/branches.html#working-with-multiple-bases
https://github.com/sqlalchemy/alembic/issues/167
https://medium.com/@karuhanga/of-modular-alembic-migrations-e94aee9113cd

